<?php declare(strict_types = 1);
/*
** Zabbix
** Copyright (C) 2001-2023 Zabbix SIA
** Copyright (C) 2024 Cybertrust Japan Co., Ltd.
**
** This program is free software: you can redistribute it and/or modify it under the terms of
** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
**
** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License along with this program.
** If not, see <https://www.gnu.org/licenses/>.
**/


/**
 * @var CPartial $this
 * @var array    $data
 */

$this->includeJsFile('configuration.snapshot.edit.html.js.php');

$snapshot_form = (new CForm())
	->addItem((new CVar(CCsrfTokenHelper::CSRF_TOKEN_NAME, CCsrfTokenHelper::get('snapshot')))->removeId())
	->setId($data['form_name'])
	->setName($data['form_name'])
	->setAction((new CUrl('zabbix.php'))
		->setArgument('action', $data['form_action'])
		->getUrl()
	)
	->addVar('snapshotid', $data['snapshotid']);

// Enable form submitting on Enter.
$snapshot_form->addItem((new CSubmitButton(null))->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));

// Snapshot tab.

$snapshot_tab = (new CFormGrid())
	->addItem([
		(new CLabel(_('Name'), 'name'))->setAsteriskMark(),
		new CFormField(
			(new CTextBox('name', $data['snapshot']['name'], '', DB::getFieldLength('snapshots', 'name')))
				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
				->setAriaRequired()
				->setAttribute('autofocus', 'autofocus')
		)
	])
	->addItem([
		new CLabel(_('Description'), 'description'),
		new CFormField(
			(new CTextArea('description', $data['snapshot']['description']))
				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
				->setMaxlength(DB::getFieldLength('snapshots', 'description'))
		)
	])
	->addItem([
		$data['snapshot']['type'] == ZBX_SNAPSHOT_TYPE_HOST
			? new CLabel(_('Host list'), 'host list')
			: new CLabel(_('Template list'), 'template list'),
		(new CDiv([
			(new CButton(null, _('Display')))
				->addClass(ZBX_STYLE_BTN_LINK)
				->onClick(
					'return PopUp("popup.snapshot.members", {snapshotid: '.$data['snapshotid'].'}, {dialogue_class: "modal-popup-generic"});'
				)
		]))
	]);

// main output
$tabs = (new CTabView(['id' => 'snapshot-tabs']))
	->setSelected(0)
	->addTab('snapshot-tab', _('Snapshot'), $snapshot_tab);

// Add footer buttons.
if (array_key_exists('buttons', $data)) {
	$primary_btn = array_shift($data['buttons']);
	$tabs->setFooter(makeFormFooter(
		$primary_btn,
		$data['buttons']
	));
}

$snapshot_form
	->addItem($tabs)
	->show();
