<?php declare(strict_types = 1);
/*
** Zabbix
** Copyright (C) 2001-2023 Zabbix SIA
** Copyright (C) 2024 Cybertrust Japan Co., Ltd.
**
** This program is free software: you can redistribute it and/or modify it under the terms of
** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
**
** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License along with this program.
** If not, see <https://www.gnu.org/licenses/>.
**/


/**
 * @var CView $this
 * @var array $data
 */

$this->includeJsFile('configuration.snapshot.list.js.php');

if ($data['uncheck']) {
	uncheckTableRows('snapshots');
}

switch ($data['type']) {
	case ZBX_SNAPSHOT_TYPE_HOST:
		$title = _('Host snapshots');
		$header_type_name = _('Host');
		break;
	case ZBX_SNAPSHOT_TYPE_TEMPLATE:
		$title = _('Template snapshots');
		$header_type_name = _('Template');
		break;
	default:
		$title = _('Snapshots');
		$header_type_name = '';
		break;
}

$html_page = (new CHtmlPage())
	->setTitle($title);

if (isset($data['titleSubmenu'])) {
	$html_page->setTitleSubmenu($data['titleSubmenu']);
}

$action_url = (new CUrl('zabbix.php'))->setArgument('action', $data['action']);

$filter = (new CFilter())
	->setResetUrl($action_url)
	->setProfile($data['profileIdx'])
	->setActiveTab($data['active_tab'])
	->addVar('action', $data['action'], 'filter_action')
	->addFilterTab(_('Filter'), [
		(new CFormGrid())
			->addClass(CFormGrid::ZBX_STYLE_FORM_GRID_LABEL_WIDTH_TRUE)
			->addItem([
				new CLabel(_('Name'), 'filter_name'),
				new CFormField(
					(new CTextBox('filter_name', $data['filter']['name']))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
				)
			])
	]);

$html_page->addItem($filter);

// table snapshots
$form = (new CForm())->setName('snapshots');
$header_checkbox = (new CCheckBox('all_snapshots'))->onClick("checkAll('".$form->getName()."', 'all_snapshots', 'snapshotids');");
$header_sortable_name = make_sorting_header(_('Name'), 'name', $data['sortField'], $data['sortOrder'],
	$action_url->getUrl()
);
$header_sortable_created_at = make_sorting_header(_('Created at'), 'created_at', $data['sortField'], $data['sortOrder'],
	$action_url->getUrl()
);

$table = (new CTableInfo())
	->setHeader([
		(new CColHeader($header_checkbox))->addClass(ZBX_STYLE_CELL_WIDTH),
		$header_sortable_name,
		$header_sortable_created_at,
		$header_type_name,
		_('Description')
	]);

foreach ($data['snapshots'] as $snapshot) {
	$snapshotid =  $snapshot['snapshotid'];
	$name =        $snapshot['name'];
	$created_at =  $snapshot['created_at'];
	$members =     json_decode($snapshot['members']);
	$description = $snapshot['description'];

	$substred_hoststr = implode(', ', array_slice($members, 0, intval($data['config']['max_in_table']))).((count($members) > $data['config']['max_in_table'])?' …':'');


	$table->addRow([
		new CCheckBox('snapshotids['.$snapshot['snapshotid'].']', $snapshot['snapshotid']),
		(new CLink($name, (new CUrl('zabbix.php'))
			->setArgument('action', 'snapshot.edit')
			->setArgument('snapshotid', $snapshotid)
		))
		->onClick('view.editSnapshot(event, '.json_encode($snapshotid).')'),
		zbx_date2str(DATE_TIME_FORMAT_SECONDS, $created_at),
		$substred_hoststr,
		$description
	]);
}

$form->addItem([
	$table,
	$data['paging'],
	new CActionButtonList('action', 'snapshotids', [
		'snapshot.massdelete' => [
			'content' => (new CSimpleButton(_('Delete')))
				->setAttribute('confirm', _('Delete selected snapshots?'))
				->onClick('view.massDeleteSnapshots(this);')
				->addClass(ZBX_STYLE_BTN_ALT)
				->addClass('no-chkbxrange')
				->removeAttribute('id')
		]
	], 'snapshots')
]);

$html_page
	->addItem($form)
	->show();
